==> clanlib-4.1.0.tar.gz: ClanLib-4.1.0/Sources/GL/GL1/gl1_primitives_array_provider.h <==
/*
**  ClanLib SDK
**  Copyright (c) 1997-2020 The ClanLib Team
**
**  This software is provided 'as-is', without any express or implied
**  warranty.  In no event will the authors be held liable for any damages
**  arising from the use of this software.
**
**  Permission is granted to anyone to use this software for any purpose,
**  including commercial applications, and to alter it and redistribute it
**  freely, subject to the following restrictions:
**
**  1. The origin of this software must not be misrepresented; you must not
**     claim that you wrote the original software. If you use this software
**     in a product, an acknowledgment in the product documentation would be
**     appreciated but is not required.
**  2. Altered source versions must be plainly marked as such, and must not be
**     misrepresented as being the original software.
**  3. This notice may not be removed or altered from any source distribution.
**
**  Note: Some of the libraries ClanLib may link to may have additional
**  requirements or restrictions.
**
**  File Author(s):
**
**    Magnus Norddahl
*/

#pragma once

#include "API/Display/TargetProviders/primitives_array_provider.h"

namespace clan
{
	class GL1PrimitivesArrayProvider : public PrimitivesArrayProvider
	{
	public:
		GL1PrimitivesArrayProvider();
		~GL1PrimitivesArrayProvider();

		std::vector<PrimitivesArrayProvider::VertexData> attributes;
		std::vector<bool> normalize_attributes;
		std::vector<bool> attribute_set;

		void set_attribute(int index, const VertexData &data, bool normalize) override;
	};
}

==> clanlib-4.2.0.tar.gz: ClanLib-4.2.0/Sources/GL/GL1/gl1_primitives_array_provider.h <==
/*
**  ClanLib SDK
**  Copyright (c) 1997-2020 The ClanLib Team
**
**  This software is provided 'as-is', without any express or implied
**  warranty.  In no event will the authors be held liable for any damages
**  arising from the use of this software.
**
**  Permission is granted to anyone to use this software for any purpose,
**  including commercial applications, and to alter it and redistribute it
**  freely, subject to the following restrictions:
**
**  1. The origin of this software must not be misrepresented; you must not
**     claim that you wrote the original software. If you use this software
**     in a product, an acknowledgment in the product documentation would be
**     appreciated but is not required.
**  2. Altered source versions must be plainly marked as such, and must not be
**     misrepresented as being the original software.
**  3. This notice may not be removed or altered from any source distribution.
**
**  Note: Some of the libraries ClanLib may link to may have additional
**  requirements or restrictions.
**
**  File Author(s):
**
**    Magnus Norddahl
*/

#pragma once

#include "API/Display/TargetProviders/primitives_array_provider.h"

namespace clan
{
	class GL1PrimitivesArrayProvider : public PrimitivesArrayProvider
	{
	public:
		GL1PrimitivesArrayProvider();
		~GL1PrimitivesArrayProvider() override;

		std::vector<PrimitivesArrayProvider::VertexData> attributes;
		std::vector<bool> normalize_attributes;
		std::vector<bool> attribute_set;

		void set_attribute(int index, const VertexData &data, bool normalize) override;
	};
}
